@@ -1,13 +1,13 @@
 #ifndef NDS_LOG_H
 #define NDS_LOG_H
 
-#ifndef DLLEXPORT
-#if WIN32 || WIN64
+#ifndef DLL_EXPORT
+#if defined _WIN32 || defined _WIN64
 #define DLL_EXPORT __declspec(dllexport)
 #else
 #define DLL_EXPORT
 #endif /* WIN32 || WIN64 */
-#endif /* DLLEXPORT */
+#endif /* DLL_EXPORT */
 
 DLL_EXPORT void nds_flush( );
 
