@@ -3,13 +3,13 @@
 
 #include "nds_logging.h"
 
-#ifndef DLLEXPORT
-#if WIN32 || WIN64
+#ifndef DLL_EXPORT
+#if defined _WIN32 || defined _WIN64
 #define DLL_EXPORT __declspec(dllexport)
 #else
 #define DLL_EXPORT
-#endif /* WIN32 || WIN64 */
-#endif /* DLLEXPORT */
+#endif /* _WIN32 || _WIN64 */
+#endif /* DLL_EXPORT */
 
 DLL_EXPORT void nds_flush_matlab( );
 
