@@ -336,7 +336,7 @@ main(int argc, const char* argv[]) {
 	fprintf(stderr, "Command syntax: \n");
 	fprintf(stderr, "nds_query [--version] [--server-version] [--server-protocol]\n");
 	fprintf(stderr, "          [--channel-list-pre-fetch] [--count | -k] [--hash | -h]\n");
-	fprintf(stderr, "          [-g] [-l] [-n <server>] [-p <port>]\n");
+	fprintf(stderr, "          [-g] [-l] [-n <server>] [-p <port>] [--epoch <epik>]\n");
 	fprintf(stderr, "          [-s <start-gps>] [-e <end-gps>] [-d <delta-t>]\n");
 	fprintf(stderr, "          [<channel-list>]\n");
 	fprintf(stderr, "where: \n");
@@ -356,6 +356,8 @@ main(int argc, const char* argv[]) {
         fprintf(stderr, "    --channel-list-pre-fetch");
 	fprintf(stderr, "            Force prefetching of the channel list\n");
 	fprintf(stderr, "            when communicating with version 2 servers\n");
+	fprintf(stderr, "    --epoch limit times to <epik> specified as a run name\n");
+	fprintf(stderr, "            (e.g. 'S6'), 'start-stop' or 'start:length'\n");
         fprintf(stderr, "    --sample-format    printf format for data dump\n");
         fprintf(stderr, "    --samples-per-line samples dumped per line\n");
 	fprintf(stderr, "    --version          print version of client and exit\n");
