@@ -1330,6 +1330,7 @@ nds2_buffer **nds2_fetch(
 		{
 			/* Determine number of bytes received for this channel. */
 			int nbytes = chan_reqs[i].status;
+			size_t nbytes_to_copy;
 
 			/* Check that no error condition occurred on this channel. */
 			if (nbytes < 0)
@@ -1341,12 +1342,13 @@ nds2_buffer **nds2_fetch(
 			/* Check that there is room to copy the new data. */
 			if (ptrs[i] + nbytes > ends[i])
 			{
-				errno = NDS2_UNEXPECTED_DATA_RECEIVED;
-				goto fail;
+				nbytes_to_copy = ends[i] - ptrs[i];
+			} else {
+				nbytes_to_copy = nbytes;
 			}
 
 			/* Copy the new data. */
-			memcpy(ptrs[i], block_data + chan_reqs[i].offset, (size_t) nbytes);
+			memcpy(ptrs[i], block_data + chan_reqs[i].offset, nbytes_to_copy);
 			ptrs[i] += nbytes;
 		}
 	}
@@ -1710,9 +1712,6 @@ const char *nds2_strerror(int errnum)
 		case NDS2_UNEXPECTED_CHANNELS_RECEIVED:
 			errstr = "Server sent more channels than were expected.";
 			break;
-		case NDS2_UNEXPECTED_DATA_RECEIVED:
-			errstr = "Server sent more data than were expected.";
-			break;
 		case NDS2_MINUTE_TRENDS:
 			errstr = "One or more requested channels are minute-trends, but requested start and stop times are not multiples of 60 seconds.";
 			break;
